<?php
// $Id: template.php,v 1.1.2.2 2010/01/01 17:57:28 psynaptic Exp $

/**
 * Override or insert variables into the page templates.
 *
 * @param $vars
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("page" in this case.)
 */
function clean_1kb_preprocess_page(&$vars, $hook) {
  $full_grid_classes = array();
  $main_classes = array();
  $left_classes = array();
  $content_classes = array();
  $right_classes = array();

  // Allow modules and themes to add to the classes. @todo: accept only arrays?
  if ($vars['full_grid_classes']) {
    $full_grid_classes = array($vars['full_grid_classes']);
  }
  if ($vars['main_classes']) {
    $main_classes = array($vars['main_classes']);
  }
  if ($vars['left_classes']) {
    $left_classes = array($vars['left_classes']);
  }
  if ($vars['content_classes']) {
    $content_classes = array($vars['content_classes']);
  }
  if ($vars['right_classes']) {
    $right_classes = array($vars['right_classes']);
  }

  // Dynamic layout classes.
  $columns = theme_get_setting('clean_960gs_columns');

  $full_grid_classes[] = 'column';
  $main_classes[] = 'column';
  $left_classes[] = 'column';
  $content_classes[] = 'column';
  $right_classes[] = 'column';

  // 12 columns.
  if ($columns == 12) {

    drupal_add_css(path_to_theme() .'/css/12cols.css');

    $full_grid_classes[] = 'grid_12';
    $main_classes[] = 'grid_12';

    switch ($vars['layout']) {
      case 'both':
        $left_classes[] = 'grid_3';
        $content_classes[] = 'grid_6';
        $right_classes[] = 'grid_3';
        break;
      case 'none':
        $content_classes[] = 'grid_12';
        break;
      case 'left':
        $left_classes[] = 'grid_3';
        $content_classes[] = 'grid_9';
        break;
      case 'right':
        $content_classes[] = 'grid_9';
        $right_classes[] = 'grid_3';
        break;
    }
  }

  // 16 columns.
  else {

    drupal_add_css(path_to_theme() .'/css/16cols.css');

    $full_grid_classes[] = 'grid_16';
    $main_classes[] = 'grid_16';
    
    switch ($vars['layout']) {
      case 'both':
        $left_classes[] = 'grid_4';
        $content_classes[] = 'grid_8';
        $right_classes[] = 'grid_4';
        break;
      case 'none':
        $content_classes[] = 'grid_16';
        break;
      case 'left':
        $left_classes[] = 'grid_4';
        $content_classes[] = 'grid_12';
        break;
      case 'right':
        $content_classes[] = 'grid_12';
        $right_classes[] = 'grid_4';
        break;
    }
  }

  // Generic classes, unlikey to need changing.
  $main_classes[] = 'clear-block';
  $left_classes[] = 'sidebar';
  $content_classes[] = 'clear-block';
  $right_classes[] = 'sidebar';

  $vars['full_grid_attr']['class'] .= implode(' ', $full_grid_classes);
  $vars['main_attr']['id'] = 'main';
  $vars['main_attr']['class'] .= implode(' ', $main_classes);
  $vars['left_attr']['id'] = 'left';
  $vars['left_attr']['class'] .= implode(' ', $left_classes);
  $vars['content_attr']['id'] = 'content';
  $vars['content_attr']['class'] .= implode(' ', $content_classes);
  $vars['right_attr']['id'] = 'right';
  $vars['right_attr']['class'] .= implode(' ', $right_classes);

  // Rebuild styles variable.
  $vars['styles'] = drupal_get_css(clean_css_stripped());
}
